@@ -12,9 +12,13 @@
 ##' @import data.table
 ##' @export
 
+
+
 genPhiFile <- function(data,file){
 ##     if(missing(file)) file <- NULL
 
+    
+    name.eta.phi <- NULL
     name.tab <- NULL
     SUBJECT_NO <- NULL
     
@@ -25,11 +29,13 @@ genPhiFile <- function(data,file){
     dt.names <- data.table(
         name.tab = cnames.covs[grepl(pattern="ET[A]*[1-9][0-9]*",cnames.covs)]
     )
-    dt.names[,I:=sub("ET[A]([1-9][0-9]*)","\\1",name.tab) |> as.numeric()]
+    dt.names[,I:=sub("ET[A]*([1-9][0-9]*)","\\1",name.tab) |> as.numeric()]
+    dt.names[,name.eta.phi:=sprintf("ETA(%s)",I)]
     setorder(dt.names,I)
-
+    
     
     dt.etas <- dt.covs[,c("ID",dt.names$name.tab),with=FALSE]
+    setnames(dt.etas,dt.names$name.tab,dt.names$name.eta.phi)
     dt.etas[,SUBJECT_NO:=.I]
     setcolorder(dt.etas,"SUBJECT_NO")
     
